@@ -15,12 +15,7 @@ using_source_path(File.expand_path(__dir__)) do
     end
   CODE
 
-  rails_parent =
-    if Rails.version.to_f >= 6.0
-      Rails.application.class.module_parent.to_s
-    else
-      Rails.application.class.parent.to_s
-    end
+  rails_parent = Rails.application.class.module_parent.to_s
 
   gsub_file 'config/initializers/action_mailer.rb', /ExampleApp/, rails_parent
 
@@ -31,6 +26,7 @@ using_source_path(File.expand_path(__dir__)) do
   if skip_active_record?
     comment_lines 'spec/support/default_preview_path', /active_record/
     comment_lines 'spec/support/default_preview_path', /active_storage/
+    comment_lines 'spec/support/default_preview_path', /action_mailbox/
   end
   copy_file 'spec/verify_mailer_preview_path_spec.rb'
 end
