@@ -11,46 +11,35 @@ ci_retry_script = File.join(
   'ci_retry_bundle_install.sh'
 )
 function_script_file = File.join(rspec_rails_repo_path, 'script/functions.sh')
-sqlite_initializer = File.join(rspec_rails_repo_path, "example_app_generator/config/initializers/sqlite3_fix.rb")
+capybara_backport_path = File.join(rspec_rails_repo_path, 'example_app_generator/spec/support/capybara.rb')
 
 in_root do
   prepend_to_file "Rakefile", "require 'active_support/all'"
 
   # Remove the existing rails version so we can properly use main or other
   # edge branches
-  gsub_file 'Gemfile', /^.*\bgem 'rails.*$/, ''
+  gsub_file 'Gemfile', /^.*\bgem ['"]rails.*$/, ''
+  gsub_file 'Gemfile', /^.*\bgem ['"]selenium-webdriver.*$/, ''
   gsub_file "Gemfile", /.*web-console.*/, ''
-  gsub_file "Gemfile", /.*debugger.*/, ''
+  gsub_file "Gemfile", /.*debug.*/, ''
   gsub_file "Gemfile", /.*puma.*/, ''
   gsub_file "Gemfile", /.*bootsnap.*/, ''
 
   append_to_file 'Gemfile', "gem 'rails-controller-testing'\n"
 
-  if Rails::VERSION::STRING >= '6'
-    gsub_file "Gemfile", /.*rails-controller-testing.*/, "gem 'rails-controller-testing', git: 'https://github.com/rails/rails-controller-testing'"
+  gsub_file "Gemfile", /.*rails-controller-testing.*/, "gem 'rails-controller-testing', git: 'https://github.com/rails/rails-controller-testing'"
 
-    # TODO: To remove when Rails released with https://github.com/rails/rails/pull/40281
-    append_to_file 'Gemfile', <<-EOT.gsub(/^ +\|/, '')
-      |gem 'rexml'
-    EOT
-  end
-
-  if Rails::VERSION::STRING >= '6'
-    # sqlite3 is an optional, unspecified, dependency and Rails 6.0 only supports `~> 1.4`
-    gsub_file "Gemfile", /.*gem..sqlite3.*/, "gem 'sqlite3', '~> 1.4'"
+  # sqlite3 is an optional, unspecified, dependency of which Rails 6.0 only supports `~> 1.4`, Ruby 2.7 only supports < 1.7 and Rails 8.0 only supports `~> 2.0`
+  if RUBY_VERSION.to_f < 3
+    gsub_file "Gemfile", /.*gem..sqlite3.*/, "gem 'sqlite3', '~> 1.4', '< 1.7'"
+  elsif Rails::VERSION::STRING > '8'
+    gsub_file "Gemfile", /.*gem..sqlite3.*/, "gem 'sqlite3', '~> 2.0'"
   else
-    # Similarly, Rails 5.0 only supports '~> 1.3.6'. Rails 5.1-5.2 support '~> 1.3', '>= 1.3.6'
-    gsub_file "Gemfile", /.*gem..sqlite3.*/, "gem 'sqlite3', '~> 1.3.6'"
+    gsub_file "Gemfile", /.*gem..sqlite3.*/, "gem 'sqlite3', '~> 1.4'"
   end
 
-  # webdrivers 4 up until 4.3.0 don't specify `required_ruby_version`, but contain
-  # Ruby 2.2-incompatible syntax (safe navigation).
-  # That basically means we use pre-4.0 for Ruby 2.2, and 4.3+ for newer Rubies.
-  gsub_file "Gemfile", /.*chromedriver-helper.*/, "gem 'webdrivers', '!= 4.0.0', '!= 4.0.1', '!= 4.1.0', '!= 4.1.1', '!= 4.1.2', '!= 4.1.3', '!= 4.2.0'"
-
-  if Rails::VERSION::STRING < '6'
-    copy_file sqlite_initializer, 'config/initializers/sqlite3_fix.rb'
-  end
+  # remove webdrivers
+  gsub_file "Gemfile", /gem ['"]webdrivers['"]/, ""
 
   if RUBY_ENGINE == "jruby"
     gsub_file "Gemfile", /.*jdbc.*/, ''
@@ -77,4 +66,13 @@ in_root do
             'REPLACE_BUNDLE_PATH',
             bundle_install_path
   chmod 'ci_retry_bundle_install.sh', 0755
+
+  copy_file capybara_backport_path, 'spec/support/capybara.rb'
+
+  if Rails::VERSION::STRING > '7'
+    create_file 'app/assets/config/manifest.js' do
+      "//= link application.css"
+    end
+    create_file 'app/assets/stylesheets/application.css'
+  end
 end
