@@ -8,11 +8,8 @@ module RSpec
     class Railtie < ::Rails::Railtie
       # As of Rails 5.1.0 you can register directories to work with `rake notes`
       require 'rails/source_annotation_extractor'
-      if ::Rails::VERSION::STRING >= '6.0'
-        ::Rails::SourceAnnotationExtractor::Annotation.register_directories("spec")
-      else
-        SourceAnnotationExtractor::Annotation.register_directories("spec")
-      end
+      ::Rails::SourceAnnotationExtractor::Annotation.register_directories("spec")
+
       generators = config.app_generators
       generators.integration_tool :rspec
       generators.test_framework :rspec
@@ -51,10 +48,18 @@ module RSpec
         end
       end
 
-      def config_default_preview_path(options)
-        return unless options.preview_path.blank?
+      if ::Rails::VERSION::STRING >= "7.1.0"
+        def config_default_preview_path(options)
+          return unless options.preview_paths.empty?
 
-        options.preview_path = "#{::Rails.root}/spec/mailers/previews"
+          options.preview_paths << "#{::Rails.root}/spec/mailers/previews"
+        end
+      else
+        def config_default_preview_path(options)
+          return unless options.preview_path.blank?
+
+          options.preview_path = "#{::Rails.root}/spec/mailers/previews"
+        end
       end
 
       def supports_action_mailer_previews?(config)
