@@ -1,6 +1,6 @@
 # The following code inspired and modified from Rails' `assert_response`:
 #
-#   https://github.com/rails/rails/blob/master/actionpack/lib/action_dispatch/testing/assertions/response.rb#L22-L38
+#   https://github.com/rails/rails/blob/main/actionpack/lib/action_dispatch/testing/assertions/response.rb#L22-L38
 #
 # Thank you to all the Rails devs who did the heavy lifting on this!
 
@@ -33,7 +33,7 @@ module RSpec
         # @param obj [Object] object to convert to a response
         # @return [ActionDispatch::TestResponse]
         def as_test_response(obj)
-          if ::ActionDispatch::Response === obj
+          if ::ActionDispatch::Response === obj || ::Rack::MockResponse === obj
             ::ActionDispatch::TestResponse.from_response(obj)
           elsif ::ActionDispatch::TestResponse === obj
             obj
@@ -216,11 +216,7 @@ module RSpec
           # @see Rack::Utils::SYMBOL_TO_STATUS_CODE
           # @raise [ArgumentError] if an associated code could not be found
           def set_expected_code!
-            @expected ||=
-              Rack::Utils::SYMBOL_TO_STATUS_CODE.fetch(expected_status) do
-                raise ArgumentError,
-                      "Invalid HTTP status: #{expected_status.inspect}"
-              end
+            @expected ||= Rack::Utils.status_code(expected_status)
           end
         end
 
@@ -243,7 +239,7 @@ module RSpec
 
           # @return [Array<Symbol>] of status codes which represent a HTTP status
           #   code "group"
-          # @see https://github.com/rails/rails/blob/master/actionpack/lib/action_dispatch/testing/test_response.rb `ActionDispatch::TestResponse`
+          # @see https://github.com/rails/rails/blob/main/actionpack/lib/action_dispatch/testing/test_response.rb `ActionDispatch::TestResponse`
           def self.valid_statuses
             [
               :error, :success, :missing,
@@ -305,7 +301,7 @@ module RSpec
 
         private
 
-          # @return [String] formating the expected status and associated code(s)
+          # @return [String] formatting the expected status and associated code(s)
           def type_message
             @type_message ||= (expected == :error ? "an error" : "a #{expected}") +
               " status code (#{type_codes})"
@@ -313,7 +309,7 @@ module RSpec
 
           # @return [String] formatting the associated code(s) for the various
           #   status code "groups"
-          # @see https://github.com/rails/rails/blob/master/actionpack/lib/action_dispatch/testing/test_response.rb `ActionDispatch::TestResponse`
+          # @see https://github.com/rails/rails/blob/main/actionpack/lib/action_dispatch/testing/test_response.rb `ActionDispatch::TestResponse`
           # @see https://github.com/rack/rack/blob/master/lib/rack/response.rb `Rack::Response`
           def type_codes
             # At the time of this commit the most recent version of
@@ -373,7 +369,7 @@ module RSpec
       #   expect(response).to have_http_status(404)
       #   expect(page).to     have_http_status(:created)
       #
-      # @see https://github.com/rails/rails/blob/master/actionpack/lib/action_dispatch/testing/test_response.rb `ActionDispatch::TestResponse`
+      # @see https://github.com/rails/rails/blob/main/actionpack/lib/action_dispatch/testing/test_response.rb `ActionDispatch::TestResponse`
       # @see https://github.com/rack/rack/blob/master/lib/rack/utils.rb `Rack::Utils::SYMBOL_TO_STATUS_CODE`
       def have_http_status(target)
         raise ArgumentError, "Invalid HTTP status: nil" unless target
