@@ -8,23 +8,22 @@ RSpec.describe Rspec::Generators::JobGenerator, type: :generator, skip: !RSpec::
   describe 'the generated files' do
     before { run_generator [file_name] }
 
+    subject(:job_spec) { file('spec/jobs/user_job_spec.rb') }
+
     context 'with file_name without job as suffix' do
       let(:file_name) { 'user' }
-      subject { file('spec/jobs/user_job_spec.rb') }
 
-      it { is_expected.to exist }
-      it { is_expected.to contain(/require 'rails_helper'/) }
-      it { is_expected.to contain(/describe UserJob, #{type_metatag(:job)}/) }
+      it 'creates the standard boiler plate' do
+        expect(job_spec).to contain(/require 'rails_helper'/).and(contain(/describe UserJob, #{type_metatag(:job)}/))
+      end
     end
 
     context 'with file_name with job as suffix' do
       let(:file_name) { 'user_job' }
 
-      subject { file('spec/jobs/user_job_spec.rb') }
-
-      it { is_expected.to exist }
-      it { is_expected.to contain(/require 'rails_helper'/) }
-      it { is_expected.to contain(/describe UserJob, #{type_metatag(:job)}/) }
+      it 'creates the standard boiler plate' do
+        expect(job_spec).to contain(/require 'rails_helper'/).and(contain(/describe UserJob, #{type_metatag(:job)}/))
+      end
     end
   end
 end
