@@ -98,6 +98,43 @@ RSpec.describe "ActiveJob matchers", skip: !RSpec::Rails::FeatureCheck.has_activ
       expect { }.not_to have_enqueued_job
     end
 
+    context "when previously enqueued jobs were performed" do
+      include ActiveJob::TestHelper
+
+      before { stub_const("HeavyLiftingJob", heavy_lifting_job) }
+
+      it "counts newly enqueued jobs" do
+        heavy_lifting_job.perform_later
+        expect {
+          perform_enqueued_jobs
+          hello_job.perform_later
+        }.to have_enqueued_job(hello_job)
+      end
+    end
+
+    context "when job is retried" do
+      include ActiveJob::TestHelper
+
+      let(:unreliable_job) do
+        Class.new(ActiveJob::Base) do
+          retry_on StandardError, wait: 5, queue: :retry
+
+          def self.name; "UnreliableJob"; end
+          def perform; raise StandardError; end
+        end
+      end
+
+      before { stub_const("UnreliableJob", unreliable_job) }
+
+      it "passes with reenqueued job" do
+        time = Time.current.change(usec: 0)
+        travel_to time do
+          UnreliableJob.perform_later
+          expect { perform_enqueued_jobs }.to have_enqueued_job(UnreliableJob).on_queue(:retry).at(time + 5)
+        end
+      end
+    end
+
     it "fails when job is not enqueued" do
       expect {
         expect { }.to have_enqueued_job
@@ -226,7 +263,7 @@ RSpec.describe "ActiveJob matchers", skip: !RSpec::Rails::FeatureCheck.has_activ
     end
 
     it "works with time offsets" do
-      # note that Time.current does not replicate Rails behavior for 5 seconds from now.
+      # NOTE: Time.current does not replicate Rails behavior for 5 seconds from now.
       time = Time.current.change(usec: 0)
       travel_to time do
         expect { hello_job.set(wait: 5).perform_later }.to have_enqueued_job.at(time + 5)
@@ -347,14 +384,14 @@ RSpec.describe "ActiveJob matchers", skip: !RSpec::Rails::FeatureCheck.has_activ
       }
     end
 
-    it "passess deserialized arguments to with block" do
+    it "passes deserialized arguments to with block" do
       global_id_object = GlobalIdModel.new("42")
 
       expect {
         hello_job.perform_later(global_id_object, symbolized_key: "asdf")
       }.to have_enqueued_job(hello_job).with { |first_arg, second_arg|
         expect(first_arg).to eq(global_id_object)
-        expect(second_arg).to eq({symbolized_key: "asdf"})
+        expect(second_arg).to eq({ symbolized_key: "asdf" })
       }
     end
 
@@ -379,22 +416,20 @@ RSpec.describe "ActiveJob matchers", skip: !RSpec::Rails::FeatureCheck.has_activ
       }
     end
 
-    if Rails.version.to_f >= 6.0
-      it "passes with Time" do
-        usec_time = Time.iso8601('2016-07-01T00:00:00.000001Z')
+    it "passes with Time" do
+      usec_time = Time.iso8601('2016-07-01T00:00:00.000001Z')
 
-        expect {
-          hello_job.perform_later(usec_time)
-        }.to have_enqueued_job(hello_job).with(usec_time)
-      end
+      expect {
+        hello_job.perform_later(usec_time)
+      }.to have_enqueued_job(hello_job).with(usec_time)
+    end
 
-      it "passes with ActiveSupport::TimeWithZone" do
-        usec_time = Time.iso8601('2016-07-01T00:00:00.000001Z').in_time_zone
+    it "passes with ActiveSupport::TimeWithZone" do
+      usec_time = Time.iso8601('2016-07-01T00:00:00.000001Z').in_time_zone
 
-        expect {
-          hello_job.perform_later(usec_time)
-        }.to have_enqueued_job(hello_job).with(usec_time)
-      end
+      expect {
+        hello_job.perform_later(usec_time)
+      }.to have_enqueued_job(hello_job).with(usec_time)
     end
   end
 
@@ -650,14 +685,14 @@ RSpec.describe "ActiveJob matchers", skip: !RSpec::Rails::FeatureCheck.has_activ
       }
     end
 
-    it "passess deserialized arguments to with block" do
+    it "passes deserialized arguments to with block" do
       global_id_object = GlobalIdModel.new("42")
 
       expect {
         hello_job.perform_later(global_id_object, symbolized_key: "asdf")
       }.to have_performed_job(hello_job).with { |first_arg, second_arg|
         expect(first_arg).to eq(global_id_object)
-        expect(second_arg).to eq({symbolized_key: "asdf"})
+        expect(second_arg).to eq({ symbolized_key: "asdf" })
       }
     end
 
