@@ -5,7 +5,7 @@ module RSpecRails
     config.secret_key_base = 'ASecretString'
 
     if defined?(ActionCable)
-      ActionCable.server.config.cable = {"adapter" => "test"}
+      ActionCable.server.config.cable = { "adapter" => "test" }
       ActionCable.server.config.logger =
         ActiveSupport::TaggedLogging.new ActiveSupport::Logger.new(StringIO.new)
     end
@@ -35,6 +35,11 @@ class RSpec::Core::ExampleGroup
   end
 end
 
+# This behaviour will become the default in Rails 8, for now it silences a deprecation
+if ActiveSupport.respond_to?(:to_time_preserves_timezone)
+  ActiveSupport.to_time_preserves_timezone = true
+end
+
 # See http://rubydoc.info/gems/rspec-core/RSpec/Core/Configuration
 RSpec.configure do |config|
   config.expect_with :rspec do |expectations|
